Crate aykroyd_derive

Crate aykroyd_derive 

Derive Macros

FromColumnsIndexed
Derive macro available if aykroyd is built with features = ["derive"].
FromColumnsNamed
Derive macro available if aykroyd is built with features = ["derive"].
FromRow
Derive macro available if aykroyd is built with features = ["derive"].
Query
Derive macro available if aykroyd is built with features = ["derive"].
QueryOne
Derive macro available if aykroyd is built with features = ["derive"].
Statement
Derive macro available if aykroyd is built with features = ["derive"].